@@ -839,7 +839,7 @@ class VariableOsPython(ReadonlyVariable):
             reverse=True):
             return "python{SLOT}".format(**atom)
 
-class VariableClTemplatesWrongPatch(Variable):
+class VariableClTemplateWrongPatch(Variable):
     """
     Действие выполняемое в случае если патч в EBUILD_PHASE=configure не подходит
     """
